package com.fs.company.service;

import java.util.List;
import com.fs.company.domain.CompanyProduct;

/**
 * 产品Service接口
 *
 * @author fs
 * @date 2025-07-01
 */
public interface ICompanyProductService
{
    /**
     * 查询产品
     *
     * @param id 产品主键
     * @return 产品
     */
    public CompanyProduct selectCompanyProductById(Long id);

    /**
     * 查询产品列表
     *
     * @param companyProduct 产品
     * @return 产品集合
     */
    public List<CompanyProduct> selectCompanyProductList(CompanyProduct companyProduct);

    List<CompanyProduct> queryAllProduct(Long companyId);

    /**
     * 新增产品
     *
     * @param companyProduct 产品
     * @return 结果
     */
    public int insertCompanyProduct(CompanyProduct companyProduct);

    /**
     * 修改产品
     *
     * @param companyProduct 产品
     * @return 结果
     */
    public int updateCompanyProduct(CompanyProduct companyProduct);

    /**
     * 批量删除产品
     *
     * @param ids 需要删除的产品主键集合
     * @return 结果
     */
    public int deleteCompanyProductByIds(Long[] ids);

    /**
     * 删除产品信息
     *
     * @param id 产品主键
     * @return 结果
     */
    public int deleteCompanyProductById(Long id);
}
